@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-cookie-manager.h,v 1.8 2005/01/14 23:54:52 chpe Exp $
+ *  $Id: ephy-cookie-manager.h,v 1.9 2005/07/03 21:38:54 jframeau Exp $
  */
 
 #ifndef EPHY_COOKIE_MANAGER_H
@@ -24,6 +24,7 @@
 
 #include <glib-object.h>
 #include <glib.h>
+#include <time.h>
 
 G_BEGIN_DECLS
 
@@ -45,7 +46,7 @@ typedef struct
 	char *value;
 	char *domain;
 	char *path;
-	gulong expires;
+	time_t expires;
 	glong real_expires;
         guint is_secure : 1;
         guint is_session : 1;
