@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-embed.h,v 1.60 2005/11/01 12:46:06 chpe Exp $
+ *  $Id: ephy-embed.h,v 1.62 2005/12/07 17:54:56 chpe Exp $
  */
 
 #ifndef EPHY_EMBED_H
@@ -192,6 +192,13 @@ struct _EphyEmbedIface
 	void		   (* set_zoom)			(EphyEmbed *embed,
 							 float zoom);
 	float		   (* get_zoom)			(EphyEmbed *embed);
+	void		   (* scroll_lines)		(EphyEmbed *embed,
+							 int num_lines);
+	void		   (* scroll_pages)		(EphyEmbed *embed,
+	 						 int num_pages);
+	void		   (* scroll_pixels)		(EphyEmbed *embed,
+							 int dx,
+							 int dy);
 	char *		   (* get_encoding)		(EphyEmbed *embed);
 	gboolean	   (* has_automatic_encoding)	(EphyEmbed *embed);
 	void		   (* set_encoding)		(EphyEmbed *embed,
@@ -205,6 +212,7 @@ struct _EphyEmbedIface
 							 int page);
 	gboolean	   (* has_modified_forms)	(EphyEmbed *embed);
 	void		   (* close)			(EphyEmbed *embed);
+
 };
 
 GType 		  ephy_embed_net_state_get_type		(void);
@@ -283,6 +291,17 @@ void		  ephy_embed_set_zoom			(EphyEmbed *embed,
 
 float		  ephy_embed_get_zoom			(EphyEmbed *embed);
 
+/* Scroll */
+void		  ephy_embed_scroll			(EphyEmbed *embed,
+							 int num_lines);
+
+void		  ephy_embed_page_scroll		(EphyEmbed *embed,
+							 int num_pages);
+							 
+void		  ephy_embed_scroll_pixels		(EphyEmbed *embed,
+							 int dx,
+							 int dy);
+
 /* Encoding */
 char		 *ephy_embed_get_encoding		(EphyEmbed *embed);
 
