@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EphyAboutModule.cpp,v 1.4 2005/07/27 22:16:53 chpe Exp $
+ *  $Id: EphyAboutModule.cpp,v 1.9 2005/11/13 17:44:08 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -38,11 +38,14 @@
 #include <nsNetCID.h>
 #include <nsString.h>
 #include <nsEscape.h>
+#include <nsAutoPtr.h>
+#include <nsNetUtil.h>
 
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
 
 #include "EphyAboutModule.h"
+#include "EphyRedirectChannel.h"
 #include "EphyUtils.h"
 
 #include "ephy-debug.h"
@@ -71,12 +74,19 @@ EphyAboutModule::NewChannel(nsIURI *aURI,
 	nsCAutoString path;
 	aURI->GetPath (path);
 
-	if (strncmp (path.get(), "neterror", strlen ("neterror")) == 0)
+#ifdef HAVE_GECKO_1_8
+	if (strncmp (path.get(), "neterror?", strlen ("neterror?")) == 0)
 	{
 		return CreateErrorPage (aURI, _retval);
 	}
+#endif
 
-	if (strncmp (path.get (), "epiphany", strlen ("epiphany")) == 0)
+	if (strncmp (path.get (), "recover?", strlen ("recover?")) == 0)
+	{
+		return CreateRecoverPage (aURI, _retval);
+	}
+
+	if (strcmp (path.get (), "epiphany") == 0)
 	{
 		return Redirect (nsDependentCString ("file://" SHARE_DIR "/epiphany.xhtml"), _retval);
 	}
@@ -90,6 +100,8 @@ nsresult
 EphyAboutModule::Redirect(const nsACString &aURL,
 			  nsIChannel **_retval)
 {
+	*_retval = nsnull;
+
 	nsresult rv;
 	nsCOMPtr<nsIIOService> ioService;
 	rv = EphyUtils::GetIOService (getter_AddRefs (ioService));
@@ -116,18 +128,20 @@ EphyAboutModule::Redirect(const nsACString &aURL,
 	rv = tempChannel->SetOwner(principal);
 	NS_ENSURE_SUCCESS (rv, rv);
 
-	NS_ADDREF(*_retval = tempChannel);
-	return rv;
+	tempChannel.swap (*_retval);
+
+	return NS_OK;
 }
 
 nsresult
-EphyAboutModule::ParseErrorURL(const char *aURL,
-			       nsACString &aError,
-			       nsACString &aRawOriginURL,
-			       nsACString &aOriginURL,
-			       nsACString &aOriginCharset)
+EphyAboutModule::ParseURL(const char *aURL,
+			  nsACString &aCode,
+			  nsACString &aRawOriginURL,
+			  nsACString &aOriginURL,
+			  nsACString &aOriginCharset,
+			  nsACString &aTitle)
 {
-	/* The error page URL is of the form "epiphany:error?e=<error>&u=<URL>&c=<charset>&d=<description>" */
+	/* The page URL is of the form "about:neterror?e=<errorcode>&u=<URL>&c=<charset>&d=<description>" */
 	const char *query = strstr (aURL, "?");
 	if (!query) return NS_ERROR_FAILURE;
 	
@@ -146,7 +160,7 @@ EphyAboutModule::ParseErrorURL(const char *aURL,
 		switch (param[0])
 		{
 			case 'e':
-				aError.Assign (nsUnescape (param + 2));
+				aCode.Assign (nsUnescape (param + 2));
 				break;
 			case 'u':
 				aRawOriginURL.Assign (param + 2);
@@ -155,6 +169,10 @@ EphyAboutModule::ParseErrorURL(const char *aURL,
 			case 'c':
 				aOriginCharset.Assign (nsUnescape (param + 2));
 				break;
+			/* The next one is not used in neterror but recover: */
+			case 't':
+				aTitle.Assign (nsUnescape (param + 2));
+				break;
 			case 'd':
 				/* we don't need mozilla's description parameter */
 			default:
@@ -163,23 +181,30 @@ EphyAboutModule::ParseErrorURL(const char *aURL,
 	}
 
 	g_strfreev (params);
-	
+
 	return NS_OK;
 }
 
+#ifdef HAVE_GECKO_1_8
 nsresult
 EphyAboutModule::GetErrorMessage(nsIURI *aURI,
 				 const char *aError,
+				 char **aStockIcon,
+				 char **aTitle,
 				 char **aPrimary,
 				 char **aSecondary,
 				 char **aTertiary,
 				 char **aLinkIntro)
 {
+	*aStockIcon = GTK_STOCK_DIALOG_ERROR;
+
 	if (strcmp (aError, "protocolNotFound") == 0)
 	{
 		nsCAutoString scheme;
 		aURI->GetScheme (scheme);
 
+		/* Translators: %s is the name of a protocol, like "http" etc. */
+		*aTitle = g_strdup_printf (_("“%s” Protocol is not Supported"), scheme.get());
 		/* Translators: %s is the name of a protocol, like "http" etc. */
 		*aPrimary = g_strdup_printf (_("“%s” protocol is not supported."), scheme.get());
 		/* FIXME: get the list of supported protocols from necko */
@@ -191,6 +216,8 @@ EphyAboutModule::GetErrorMessage(nsIURI *aURI,
 		nsCAutoString path;
 		aURI->GetPath (path);
 
+		/* Translators: %s is the path and filename, for example "/home/user/test.html" */
+		*aTitle = g_markup_printf_escaped (_("File “%s” not Found"), path.get());
 		/* Translators: %s is the path and filename, for example "/home/user/test.html" */
 		*aPrimary = g_markup_printf_escaped (_("File “%s” not found."), path.get());
 		*aSecondary = _("Check the location of the file and try again.");
@@ -200,6 +227,9 @@ EphyAboutModule::GetErrorMessage(nsIURI *aURI,
 		nsCAutoString host;
 		aURI->GetHost (host);
 
+		/* Translators: %s is the hostname, like "www.example.com" */
+		*aTitle = g_markup_printf_escaped (_("“%s” Could not be Found"),
+						     host.get());
 		/* Translators: %s is the hostname, like "www.example.com" */
 		*aPrimary = g_markup_printf_escaped (_("“%s” could not be found."),
 						     host.get());
@@ -212,6 +242,10 @@ EphyAboutModule::GetErrorMessage(nsIURI *aURI,
 		nsCAutoString host;
 		aURI->GetHost (host);
 
+		/* Translators: %s is the hostname, like "www.example.com" */
+		*aTitle = g_markup_printf_escaped
+				(_("“%s” Refused the Connection"),
+				 host.get());
 		/* Translators: %s is the hostname, like "www.example.com" */
 		*aPrimary = g_markup_printf_escaped
 				(_("“%s” refused the connection."),
@@ -225,6 +259,10 @@ EphyAboutModule::GetErrorMessage(nsIURI *aURI,
 		nsCAutoString host;
 		aURI->GetHost (host);
 
+		/* Translators: %s is the hostname, like "www.example.com" */
+		*aTitle = g_markup_printf_escaped
+				(_("“%s” Interrupted the Connection"),
+				 host.get());
 		/* Translators: %s is the hostname, like "www.example.com" */
 		*aPrimary = g_markup_printf_escaped
 				(_("“%s” interrupted the connection."),
@@ -238,6 +276,10 @@ EphyAboutModule::GetErrorMessage(nsIURI *aURI,
 		nsCAutoString host;
 		aURI->GetHost (host);
 
+		/* Translators: %s is the hostname, like "www.example.com" */
+		*aTitle = g_markup_printf_escaped
+				(_("“%s” is not Responding"),
+				 host.get());
 		/* Translators: %s is the hostname, like "www.example.com" */
 		*aPrimary = g_markup_printf_escaped
 				(_("“%s” is not responding."),
@@ -250,6 +292,7 @@ EphyAboutModule::GetErrorMessage(nsIURI *aURI,
 	}
 	else if (strcmp (aError, "malformedURI") == 0)
 	{
+		*aTitle = g_strdup (_("Invalid Address"));
 		*aPrimary = g_strdup (_("Invalid address."));
 		*aSecondary = g_strdup (_("The address you entered is not valid."));
 	}
@@ -258,6 +301,10 @@ EphyAboutModule::GetErrorMessage(nsIURI *aURI,
 		nsCAutoString host;
 		aURI->GetHost (host);
 
+		/* Translators: %s is the hostname, like "www.example.com" */
+		*aTitle = g_markup_printf_escaped
+				(_("“%s” Redirected Too Many Times"),
+				 host.get());
 		/* Translators: %s is the hostname, like "www.example.com" */
 		*aPrimary = g_markup_printf_escaped
 				(_("“%s” redirected too many times."),
@@ -270,6 +317,10 @@ EphyAboutModule::GetErrorMessage(nsIURI *aURI,
 		nsCAutoString host;
 		aURI->GetHost (host);
 
+		/* Translators: %s is the hostname, like "www.example.com" */
+		*aTitle = g_markup_printf_escaped
+				(_("“%s” Requires an Encrypted Connection"),
+				 host.get());
 		/* Translators: %s is the hostname, like "www.example.com" */
 		*aPrimary = g_markup_printf_escaped
 				(_("“%s” requires an encrypted connection."),
@@ -282,6 +333,10 @@ EphyAboutModule::GetErrorMessage(nsIURI *aURI,
 		nsCAutoString host;
 		aURI->GetHost (host);
 
+		/* Translators: %s is the hostname, like "www.example.com" */
+		*aTitle = g_markup_printf_escaped
+				(_("“%s” Dropped the Connection"),
+				 host.get());
 		/* Translators: %s is the hostname, like "www.example.com" */
 		*aPrimary = g_markup_printf_escaped
 				(_("“%s” dropped the connection."),
@@ -294,10 +349,12 @@ EphyAboutModule::GetErrorMessage(nsIURI *aURI,
 	}
 	else if (strcmp (aError, "netOffline") == 0)
 	{
-		*aPrimary = g_strdup (_("Cannot load document in offline mode."));
-		*aSecondary = _("This document cannot be viewed in offline "
-				"mode. Set Epiphany to “online” "
-				"and try again.");
+		/* Error is a bit too strong here */
+		*aStockIcon = GTK_STOCK_DIALOG_INFO;
+
+		*aTitle = g_strdup (_("Cannot Load Document Whilst Working Offline"));
+		*aPrimary = g_strdup (_("Cannot load document whilst working offline."));
+		*aSecondary = _("To view this document, disable “Work Offline” and try again.");
 	}
 	else if (strcmp (aError, "deniedPortAccess") == 0)
 	{
@@ -307,6 +364,10 @@ EphyAboutModule::GetErrorMessage(nsIURI *aURI,
 		PRInt32 port = -1;
 		aURI->GetPort (&port);
 
+		/* Translators: %s is the hostname, like "www.example.com" */
+		*aTitle = g_markup_printf_escaped
+				(_("“%s” Denied Access to Port “%d”"),
+				 host.get(), port > 0 ? port : 80);
 		/* Translators: %s is the hostname, like "www.example.com" */
 		*aPrimary = g_markup_printf_escaped
 				(_("“%s” denied access to port “%d”."),
@@ -320,12 +381,20 @@ EphyAboutModule::GetErrorMessage(nsIURI *aURI,
 	else if (strcmp (aError, "proxyResolveFailure") == 0 ||
 		 strcmp (aError, "proxyConnectFailure") == 0)
 	{
+		*aTitle = g_strdup (_("Could not Connect to Proxy Server"));
 		*aPrimary = g_strdup (_("Could not connect to proxy server."));
 		*aSecondary = _("Check your proxy server settings. "
 				"If the connection still fails, there may be "
 				"a problem with your proxy server or your "
 				"network connection.");
 	}
+	/* This was introduced in gecko 1.9 */
+	else if (strcmp (aError, "contentEncodingError") == 0)
+	{
+		*aTitle = g_strdup (_("Could not Display Content"));
+		*aPrimary = g_strdup (_("Could not display content."));
+		*aSecondary = _("The page uses an unsupported or invalid form of compression.");
+	}
 	else
 	{
 		return NS_ERROR_ILLEGAL_VALUE;
@@ -338,23 +407,28 @@ nsresult
 EphyAboutModule::CreateErrorPage(nsIURI *aErrorURI,
 				 nsIChannel **_retval)
 {
+	*_retval = nsnull;
+
         /* First parse the arguments */
-        nsresult rv = NS_ERROR_ILLEGAL_VALUE;
+	nsresult rv;
         nsCAutoString spec;
 	rv = aErrorURI->GetSpec (spec);
-	NS_ENSURE_TRUE (NS_SUCCEEDED (rv) && !spec.IsEmpty(), rv);
+	NS_ENSURE_TRUE (NS_SUCCEEDED (rv), rv);
 
-	nsCAutoString error, rawurl, url, charset;
-	rv = ParseErrorURL (spec.get (), error, rawurl, url, charset);
-	if (NS_FAILED (rv) || error.IsEmpty () || url.IsEmpty()) return rv;
+	nsCAutoString error, rawurl, url, charset, dummy;
+	rv = ParseURL (spec.get (), error, rawurl, url, charset, dummy);
+	if (NS_FAILED (rv)) return rv;
+	if (error.IsEmpty () || rawurl.IsEmpty () || url.IsEmpty()) return NS_ERROR_FAILURE;
 
 	nsCOMPtr<nsIURI> uri;
 	rv = EphyUtils::NewURI(getter_AddRefs (uri), url, charset.get());
 	/* FIXME can uri be NULL if the original url was invalid? */
-	NS_ENSURE_TRUE (NS_SUCCEEDED (rv) && uri, rv);
+	NS_ENSURE_SUCCESS (rv, rv);
 
-	char *primary = nsnull, *secondary = nsnull, *tertiary = nsnull, *linkintro = nsnull;
-	rv = GetErrorMessage (uri, error.get(), &primary, &secondary, &tertiary, &linkintro);
+	char *stock_id = nsnull, *title = nsnull, *primary = nsnull,
+	     *secondary = nsnull, *tertiary = nsnull, *linkintro = nsnull;
+	rv = GetErrorMessage (uri, error.get(), &stock_id, &title, &primary,
+			      &secondary, &tertiary, &linkintro);
 
 	/* we don't know about this error code.
 	 * FIXME: We'd like to forward to mozilla's about:neterror handler,
@@ -363,24 +437,94 @@ EphyAboutModule::CreateErrorPage(nsIURI *aErrorURI,
 	 */
 	if (rv == NS_ERROR_ILLEGAL_VALUE)
 	{
-		nsCAutoString url(spec);
+		nsCAutoString newurl(spec);
 
 		/* remove "about:neterror" part and insert mozilla's error page url */
-		url.Cut(0, strlen ("about:neterror"));
-		url.Insert("chrome://global/content/netError.xhtml", 0);
+		newurl.Cut(0, strlen ("about:neterror"));
+		newurl.Insert("chrome://global/content/netError.xhtml", 0);
 
-		return Redirect (url, _retval);
+		return Redirect (newurl, _retval);
 	}
-
+	NS_ENSURE_SUCCESS (rv, rv);
 	NS_ENSURE_TRUE (primary && secondary, NS_ERROR_FAILURE);
 
-	/* open the rendering stream */
+	nsCOMPtr<nsIChannel> channel;
+	rv = WritePage (aErrorURI, uri, aErrorURI, rawurl, title, stock_id, primary, secondary, tertiary, linkintro, getter_AddRefs (channel));
+	NS_ENSURE_SUCCESS (rv, rv);
+
+	g_free (title);
+	g_free (primary);
+
+	channel.swap (*_retval);
+
+	return NS_OK;
+}
+#endif /* HAVE_GECKO_1_8 */
+
+nsresult
+EphyAboutModule::CreateRecoverPage(nsIURI *aRecoverURI,
+				   nsIChannel **_retval)
+{
+	*_retval = nsnull;
+
+        /* First parse the arguments */
+	nsresult rv;
+        nsCAutoString spec;
+	rv = aRecoverURI->GetSpec (spec);
+	NS_ENSURE_TRUE (NS_SUCCEEDED (rv), rv);
+
+	nsCAutoString error, rawurl, url, charset, title;
+	rv = ParseURL (spec.get (), error, rawurl, url, charset, title);
+	if (NS_FAILED (rv)) return rv;
+	if (rawurl.IsEmpty () || url.IsEmpty()) return NS_ERROR_FAILURE;
+
+	nsCOMPtr<nsIURI> uri;
+	rv = EphyUtils::NewURI(getter_AddRefs (uri), url, charset.get());
+	NS_ENSURE_SUCCESS (rv, rv);
+
+	char *secondary = g_strdup_printf
+		(_("The page “%s” in this tab was not fully loaded yet when "
+		   "the web browser crashed; it could have caused the crash."),
+		 url.get());
+
+	nsCOMPtr<nsIChannel> channel;
+	rv = WritePage (aRecoverURI, uri, uri, rawurl, title.get(),
+			GTK_STOCK_DIALOG_INFO, title.get() /* as primary */,
+			secondary, nsnull, nsnull, getter_AddRefs (channel));
+	NS_ENSURE_SUCCESS (rv, rv);
+
+	nsRefPtr<EphyRedirectChannel> redirectChannel (new EphyRedirectChannel (channel));
+	if (!redirectChannel) return NS_ERROR_OUT_OF_MEMORY;
+
+	g_free (secondary);
+
+	NS_ADDREF(*_retval = redirectChannel);
+
+	return NS_OK;
+}
+
+nsresult
+EphyAboutModule::WritePage(nsIURI *aOriginalURI,
+			   nsIURI *aURI,
+			   nsIURI *aChannelURI,
+			   const nsACString &aRawURL,
+			   const char *aTitle,
+			   const char *aStockIcon,
+			   const char *aPrimary,
+			   const char *aSecondary,
+			   const char *aTertiary,
+			   const char *aLinkIntro,
+			   nsIChannel **_retval)
+{
+	*_retval = nsnull;
+
+	nsresult rv;
 	nsCOMPtr<nsIStorageStream> storageStream;
-	rv = NS_NewStorageStream(16384, (PRUint32) -1, getter_AddRefs (storageStream));
+	rv = NS_NewStorageStream (16384, (PRUint32) -1, getter_AddRefs (storageStream));
 	NS_ENSURE_SUCCESS (rv, rv);
 
 	nsCOMPtr<nsIOutputStream> stream;
-	rv = storageStream->GetOutputStream(0, getter_AddRefs (stream));
+	rv = storageStream->GetOutputStream (0, getter_AddRefs (stream));
 	NS_ENSURE_SUCCESS (rv, rv);
 
 	char *language = g_strdup (pango_language_to_string (gtk_get_default_language ()));
@@ -399,7 +543,7 @@ EphyAboutModule::CreateErrorPage(nsIURI *aErrorURI,
 	       "\">\n"
 	       "<head>\n"
 		"<title>");
-	Write (stream, primary);
+	Write (stream, aTitle);
 	/* no favicon for now, it would pollute the favicon cache */
 	/* "<link rel=\"icon\" type=\"image/png\" href=\"moz-icon://stock/gtk-dialog-error?size=16\" />\n" */
 	Write (stream,
@@ -412,7 +556,10 @@ EphyAboutModule::CreateErrorPage(nsIURI *aErrorURI,
 			"left: 12px;\n"
 			"overflow: auto;\n"
 
-			"background: -moz-dialog url('moz-icon://stock/gtk-dialog-error?size=dialog') no-repeat 12px 12px;\n"
+			"background: -moz-dialog url('moz-icon://stock/");
+	Write (stream, aStockIcon);
+	Write (stream,
+			"?size=dialog') no-repeat 12px 12px;\n"
 			"color: -moz-dialogtext;\n"
 			"font: message-box;\n"
 			"border: 1px solid -moz-dialogtext;\n"
@@ -433,29 +580,33 @@ EphyAboutModule::CreateErrorPage(nsIURI *aErrorURI,
 	       "\">\n"
 		"<div id=\"body\">"
 		"<h1>");
-	Write (stream, primary);
+	Write (stream, aTitle);
 	Write (stream,
-	       "</h1>\n"
-	       "<p>");
-	Write (stream, secondary);
-	if (tertiary)
-	{
-		Write (stream, " ");
-		Write (stream, tertiary);
-	}
-	Write (stream,
-		"</p>\n");
-
-	PRBool isHttp = PR_FALSE, isHttps = PR_FALSE;
-	uri->SchemeIs ("http", &isHttp);
-	uri->SchemeIs ("https", &isHttps);
-	if (linkintro && (isHttp || isHttps))
+	       "</h1>\n");
+	if (aSecondary)
 	{
 		Write (stream, "<p>");
-		Write (stream, linkintro);
+		Write (stream, aSecondary);
+		if (aTertiary)
+		{
+			Write (stream, " ");
+			Write (stream, aTertiary);
+		}
+		Write (stream, "</p>\n");
+	}
+
+	PRBool isHttp = PR_FALSE, isHttps = PR_FALSE;
+	aURI->SchemeIs ("http", &isHttp);
+	aURI->SchemeIs ("https", &isHttps);
+	if (aLinkIntro && (isHttp || isHttps))
+	{
+		nsCString raw(aRawURL);
+
+		Write (stream, "<p>");
+		Write (stream, aLinkIntro);
 		Write (stream, "<ul>\n");
 		Write (stream, "<li><a href=\"http://www.google.com/search?q=cache:");
-		Write (stream, rawurl.get());
+		Write (stream, raw.get());
 		Write (stream, "\">");
 		/* Translators: The text before the "|" is context to help you decide on
 		 * the correct translation. You MUST OMIT it in the translated string. */
@@ -463,7 +614,7 @@ EphyAboutModule::CreateErrorPage(nsIURI *aErrorURI,
 		Write (stream, "</a></li>\n");
 
 		Write (stream, "<li><a href=\"http://web.archive.org/web/*/");
-		Write (stream, rawurl.get());
+		Write (stream, raw.get());
 		Write (stream, "\">");
 		/* Translators: The text before the "|" is context to help you decide on
 		 * the correct translation. You MUST OMIT it in the translated string. */
@@ -479,20 +630,21 @@ EphyAboutModule::CreateErrorPage(nsIURI *aErrorURI,
 	       "</html>\n");
 
 	g_free (language);
-	g_free (primary);
  
 	/* finish the rendering */
 	nsCOMPtr<nsIInputStream> inputStream;
-	rv = storageStream->NewInputStream(0, getter_AddRefs (inputStream));
+	rv = storageStream->NewInputStream (0, getter_AddRefs (inputStream));
 	NS_ENSURE_SUCCESS (rv, rv);
 
-	nsCOMPtr<nsIInputStreamChannel> channel (do_CreateInstance ("@mozilla.org/network/input-stream-channel;1", &rv));
+	nsCOMPtr<nsIChannel> channel;
+	rv = NS_NewInputStreamChannel (getter_AddRefs (channel),
+				       aChannelURI,
+				       inputStream,
+				       NS_LITERAL_CSTRING ("application/xhtml+xml"),
+				       NS_LITERAL_CSTRING ("utf-8"));
 	NS_ENSURE_SUCCESS (rv, rv);
-
-	rv |= channel->SetURI (aErrorURI);
-	rv |= channel->SetContentStream (inputStream);
-	rv |= channel->SetContentType (NS_LITERAL_CSTRING ("application/xhtml+xml"));
-	rv |= channel->SetContentCharset (NS_LITERAL_CSTRING ("utf-8"));
+	
+	rv = channel->SetOriginalURI (aOriginalURI);
 	NS_ENSURE_SUCCESS (rv, rv);
 
 	nsCOMPtr<nsIScriptSecurityManager> securityManager 
@@ -500,14 +652,15 @@ EphyAboutModule::CreateErrorPage(nsIURI *aErrorURI,
 	NS_ENSURE_SUCCESS (rv, rv);
 
 	nsCOMPtr<nsIPrincipal> principal;
-	rv = securityManager->GetCodebasePrincipal (aErrorURI, getter_AddRefs (principal));
+	rv = securityManager->GetCodebasePrincipal (aOriginalURI, getter_AddRefs (principal));
 	NS_ENSURE_SUCCESS (rv, rv);
 
 	rv = channel->SetOwner(principal);
 	NS_ENSURE_SUCCESS (rv, rv);
 
-	NS_ADDREF(*_retval = channel);
-	return rv;
+	channel.swap (*_retval);
+
+	return NS_OK;
 }
 
 nsresult
