@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-gui.c,v 1.37 2005/05/29 14:29:02 jframeau Exp $
+ *  $Id: ephy-gui.c,v 1.44 2005/12/11 17:27:13 chpe Exp $
  */
 
 #include "config.h"
@@ -37,6 +37,7 @@
 #include <gtk/gtkstock.h>
 #include <gtk/gtkmain.h>
 #include <gtk/gtktreeselection.h>
+#include <gtk/gtktoolbar.h>
 
 #include <unistd.h>
 
@@ -107,6 +108,14 @@ ephy_gui_menu_position_tree_selection (GtkMenu   *menu,
 
 /**
  * ephy_gui_menu_position_under_widget:
+ * @menu:
+ * @x:
+ * @y:
+ * @push_in:
+ * @user_data: a #GtkWidget
+ * 
+ * Positions @menu under (or over, depending on space available) the widget
+ * @user_data.
  */
 void
 ephy_gui_menu_position_under_widget (GtkMenu   *menu,
@@ -115,24 +124,130 @@ ephy_gui_menu_position_under_widget (GtkMenu   *menu,
 				     gboolean  *push_in,
 				     gpointer	user_data)
 {
-	GtkWidget *w = GTK_WIDGET (user_data);
-	GtkRequisition requisition;
+	/* Adapted from gtktoolbar.c */
+	GtkWidget *widget = GTK_WIDGET (user_data);
+	GtkWidget *container;
+	GtkRequisition req;
+	GtkRequisition menu_req;
+	GdkRectangle monitor;
+	int monitor_num;
+	GdkScreen *screen;
+  
+	g_return_if_fail (GTK_IS_WIDGET (widget));
 
-	gdk_window_get_origin (w->window, x, y);
-	gtk_widget_size_request (GTK_WIDGET (menu), &requisition);
+	container = gtk_widget_get_ancestor (widget, GTK_TYPE_CONTAINER);
+	g_return_if_fail (container != NULL);
 
-	if (gtk_widget_get_direction (w) == GTK_TEXT_DIR_RTL)
+	gtk_widget_size_request (widget, &req);
+	gtk_widget_size_request (GTK_WIDGET (menu), &menu_req);
+
+	screen = gtk_widget_get_screen (GTK_WIDGET (menu));
+	monitor_num = gdk_screen_get_monitor_at_window (screen, widget->window);
+	if (monitor_num < 0)
+		monitor_num = 0;
+	gdk_screen_get_monitor_geometry (screen, monitor_num, &monitor);
+
+	gdk_window_get_origin (widget->window, x, y);
+	if (GTK_WIDGET_NO_WINDOW (widget))
 	{
-		*x += w->allocation.x + w->allocation.width - requisition.width;
+		*x += widget->allocation.x;
+		*y += widget->allocation.y;
 	}
+
+	if (gtk_widget_get_direction (container) == GTK_TEXT_DIR_LTR) 
+		*x += widget->allocation.width - req.width;
+	else 
+		*x += req.width - menu_req.width;
+
+	if ((*y + widget->allocation.height + menu_req.height) <= monitor.y + monitor.height)
+		*y += widget->allocation.height;
+	else if ((*y - menu_req.height) >= monitor.y)
+		*y -= menu_req.height;
+	else if (monitor.y + monitor.height - (*y + widget->allocation.height) > *y)
+		*y += widget->allocation.height;
 	else
+		*y -= menu_req.height;
+
+	*push_in = FALSE;
+}
+
+/**
+ * ephy_gui_menu_position_under_widget:
+ * @menu:
+ * @x:
+ * @y:
+ * @push_in:
+ * @user_data: a #GtkWidget which has to be contained in (a widget on) a #GtkToolbar
+ * 
+ * Positions @menu under (or over, depending on space available) the
+ * @user_data.
+ */
+void
+ephy_gui_menu_position_on_toolbar (GtkMenu   *menu,
+				   gint      *x,
+				   gint      *y,
+				   gboolean  *push_in,
+				   gpointer   user_data)
+{
+	/* Adapted from gtktoolbar.c */
+	GtkWidget *widget = GTK_WIDGET (user_data);
+	GtkToolbar *toolbar;
+	GtkRequisition req;
+	GtkRequisition menu_req;
+	GdkRectangle monitor;
+	int monitor_num;
+	GdkScreen *screen;
+  
+	g_return_if_fail (GTK_IS_WIDGET (widget));
+
+	toolbar = GTK_TOOLBAR (gtk_widget_get_ancestor (widget, GTK_TYPE_TOOLBAR));
+	g_return_if_fail (toolbar != NULL);
+
+	gtk_widget_size_request (widget, &req);
+	gtk_widget_size_request (GTK_WIDGET (menu), &menu_req);
+
+	screen = gtk_widget_get_screen (GTK_WIDGET (menu));
+	monitor_num = gdk_screen_get_monitor_at_window (screen, widget->window);
+	if (monitor_num < 0)
+		monitor_num = 0;
+	gdk_screen_get_monitor_geometry (screen, monitor_num, &monitor);
+
+	gdk_window_get_origin (widget->window, x, y);
+	if (GTK_WIDGET_NO_WINDOW (widget))
 	{
-		*x += w->allocation.x;
+		*x += widget->allocation.x;
+		*y += widget->allocation.y;
 	}
 
-	*y += w->allocation.y + w->allocation.height;
+	if (toolbar->orientation == GTK_ORIENTATION_HORIZONTAL)
+	{
+		if (gtk_widget_get_direction (GTK_WIDGET (toolbar)) == GTK_TEXT_DIR_LTR) 
+			*x += widget->allocation.width - req.width;
+		else 
+			*x += req.width - menu_req.width;
 
-	ephy_gui_sanitise_popup_position (menu, w, x, y);
+		if ((*y + widget->allocation.height + menu_req.height) <= monitor.y + monitor.height)
+			*y += widget->allocation.height;
+		else if ((*y - menu_req.height) >= monitor.y)
+			*y -= menu_req.height;
+		else if (monitor.y + monitor.height - (*y + widget->allocation.height) > *y)
+			*y += widget->allocation.height;
+		else
+			*y -= menu_req.height;
+	}
+	else 
+	{
+		if (gtk_widget_get_direction (GTK_WIDGET (toolbar)) == GTK_TEXT_DIR_LTR) 
+			*x += widget->allocation.width;
+		else 
+			*x -= menu_req.width;
+
+		if (*y + menu_req.height > monitor.y + monitor.height &&
+		    *y + widget->allocation.height - monitor.y > monitor.y + monitor.height - *y)
+			*y += widget->allocation.height - menu_req.height;
+	}
+
+	*push_in = FALSE;
 }
 
 void
@@ -189,12 +304,11 @@ ephy_gui_ensure_window_group (GtkWindow *window)
 }
 
 gboolean
-ephy_gui_confirm_overwrite_file (GtkWidget *parent,
-				 const char *filename)
+ephy_gui_check_location_writable (GtkWidget *parent,
+				  const char *filename)
 {
 	GtkWidget *dialog;
 	char *display_name;
-	gboolean retval;
 
 	if (filename == NULL) return FALSE;
 
@@ -211,14 +325,14 @@ ephy_gui_confirm_overwrite_file (GtkWidget *parent,
 					GTK_DIALOG_DESTROY_WITH_PARENT,
 					GTK_MESSAGE_ERROR,
 					GTK_BUTTONS_CLOSE,
-					_("Directory %s is not writable"), path);
+					_("Directory “%s” is not writable"), path);
 
 			gtk_message_dialog_format_secondary_text (
 					GTK_MESSAGE_DIALOG (dialog),
 					_("You do not have permission to "
-						"create files in this directory."));
+					  "create files in this directory."));
 
-			gtk_window_set_title (GTK_WINDOW (dialog), _("Directory not writable"));
+			gtk_window_set_title (GTK_WINDOW (dialog), _("Directory not Writable"));
 			gtk_window_set_icon_name (GTK_WINDOW (dialog), "web-browser");
 
 			if (parent != NULL)
@@ -248,13 +362,14 @@ ephy_gui_confirm_overwrite_file (GtkWidget *parent,
 				GTK_DIALOG_DESTROY_WITH_PARENT,
 				GTK_MESSAGE_ERROR,
 				GTK_BUTTONS_CLOSE,
-				_("File %s is not writable"), display_name);
+				_("Cannot overwrite existing file “%s”"), display_name);
 
 		gtk_message_dialog_format_secondary_text (
 				GTK_MESSAGE_DIALOG (dialog),
-				_("You do not have permission to overwrite this file."));
+				_("A file with this name already exists and "
+				  "you don't have permission to overwrite it."));
 
-		gtk_window_set_title (GTK_WINDOW (dialog), _("File not writable"));
+		gtk_window_set_title (GTK_WINDOW (dialog), _("Cannot Overwrite File"));
 		gtk_window_set_icon_name (GTK_WINDOW (dialog), "web-browser");
 
 		if (parent != NULL)
@@ -271,39 +386,8 @@ ephy_gui_confirm_overwrite_file (GtkWidget *parent,
 		return FALSE;
 	}
 
-	dialog = gtk_message_dialog_new
-		(parent ? GTK_WINDOW (parent) : NULL,
-		 GTK_DIALOG_DESTROY_WITH_PARENT,
-		 GTK_MESSAGE_QUESTION,
-		 GTK_BUTTONS_CANCEL,
-		 _("Overwrite \"%s\"?"), display_name);
 
-	gtk_message_dialog_format_secondary_text
-		(GTK_MESSAGE_DIALOG (dialog),
-		 _("A file with this name already exists. If you choose to "
-		   "overwrite this file, the contents will be lost."));
-
-	gtk_dialog_add_button (GTK_DIALOG (dialog),
-			       _("_Overwrite"), GTK_RESPONSE_ACCEPT);
-
-	gtk_window_set_title (GTK_WINDOW (dialog), _("Overwrite File?"));
-	gtk_window_set_icon_name (GTK_WINDOW (dialog), "web-browser");
-
-	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_CANCEL);
-
-	if (parent != NULL)
-	{
-		gtk_window_group_add_window (ephy_gui_ensure_window_group (GTK_WINDOW (parent)),
-					     GTK_WINDOW (dialog));
-	}
-
-	retval = (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT);
-
-	gtk_widget_destroy (dialog);
-
-	g_free (display_name);
-
-	return retval;
+	return TRUE;
 }
 
 void
@@ -351,7 +435,7 @@ ephy_gui_is_middle_click (void)
 
 			/* middle-click or control-click */
 			if ((button == 1 && ((state & modifiers) == GDK_CONTROL_MASK)) ||
-			    (button == 2))
+			    (button == 2 && ((state & modifiers) == 0)))
 			{
 				is_middle_click = TRUE;
 			}
