@@ -237,7 +237,56 @@ ephy_marshal_BOOLEAN__STRING (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:STRING,STRING (./ephy-marshal.list:5) */
+/* BOOLEAN:STRING,BOOLEAN,BOOLEAN (./ephy-marshal.list:5) */
+extern void ephy_marshal_BOOLEAN__STRING_BOOLEAN_BOOLEAN (GClosure     *closure,
+                                                          GValue       *return_value,
+                                                          guint         n_param_values,
+                                                          const GValue *param_values,
+                                                          gpointer      invocation_hint,
+                                                          gpointer      marshal_data);
+void
+ephy_marshal_BOOLEAN__STRING_BOOLEAN_BOOLEAN (GClosure     *closure,
+                                              GValue       *return_value,
+                                              guint         n_param_values,
+                                              const GValue *param_values,
+                                              gpointer      invocation_hint,
+                                              gpointer      marshal_data)
+{
+  typedef gboolean (*GMarshalFunc_BOOLEAN__STRING_BOOLEAN_BOOLEAN) (gpointer     data1,
+                                                                    gpointer     arg_1,
+                                                                    gboolean     arg_2,
+                                                                    gboolean     arg_3,
+                                                                    gpointer     data2);
+  register GMarshalFunc_BOOLEAN__STRING_BOOLEAN_BOOLEAN callback;
+  register GCClosure *cc = (GCClosure*) closure;
+  register gpointer data1, data2;
+  gboolean v_return;
+
+  g_return_if_fail (return_value != NULL);
+  g_return_if_fail (n_param_values == 4);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_BOOLEAN__STRING_BOOLEAN_BOOLEAN) (marshal_data ? marshal_data : cc->callback);
+
+  v_return = callback (data1,
+                       g_marshal_value_peek_string (param_values + 1),
+                       g_marshal_value_peek_boolean (param_values + 2),
+                       g_marshal_value_peek_boolean (param_values + 3),
+                       data2);
+
+  g_value_set_boolean (return_value, v_return);
+}
+
+/* BOOLEAN:STRING,STRING (./ephy-marshal.list:6) */
 extern void ephy_marshal_BOOLEAN__STRING_STRING (GClosure     *closure,
                                                  GValue       *return_value,
                                                  guint         n_param_values,
@@ -284,7 +333,7 @@ ephy_marshal_BOOLEAN__STRING_STRING (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:STRING,STRING,STRING (./ephy-marshal.list:6) */
+/* BOOLEAN:STRING,STRING,STRING (./ephy-marshal.list:7) */
 extern void ephy_marshal_BOOLEAN__STRING_STRING_STRING (GClosure     *closure,
                                                         GValue       *return_value,
                                                         guint         n_param_values,
@@ -333,7 +382,7 @@ ephy_marshal_BOOLEAN__STRING_STRING_STRING (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:VOID (./ephy-marshal.list:7) */
+/* BOOLEAN:VOID (./ephy-marshal.list:8) */
 extern void ephy_marshal_BOOLEAN__VOID (GClosure     *closure,
                                         GValue       *return_value,
                                         guint         n_param_values,
@@ -376,7 +425,7 @@ ephy_marshal_BOOLEAN__VOID (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* OBJECT:OBJECT,FLAGS (./ephy-marshal.list:8) */
+/* OBJECT:OBJECT,FLAGS (./ephy-marshal.list:9) */
 extern void ephy_marshal_OBJECT__OBJECT_FLAGS (GClosure     *closure,
                                                GValue       *return_value,
                                                guint         n_param_values,
@@ -423,7 +472,7 @@ ephy_marshal_OBJECT__OBJECT_FLAGS (GClosure     *closure,
   g_value_take_object (return_value, v_return);
 }
 
-/* OBJECT:STRING,OBJECT,FLAGS (./ephy-marshal.list:9) */
+/* OBJECT:STRING,OBJECT,FLAGS (./ephy-marshal.list:10) */
 extern void ephy_marshal_OBJECT__STRING_OBJECT_FLAGS (GClosure     *closure,
                                                       GValue       *return_value,
                                                       guint         n_param_values,
@@ -472,7 +521,7 @@ ephy_marshal_OBJECT__STRING_OBJECT_FLAGS (GClosure     *closure,
   g_value_take_object (return_value, v_return);
 }
 
-/* STRING:STRING,STRING (./ephy-marshal.list:10) */
+/* STRING:STRING,STRING (./ephy-marshal.list:11) */
 extern void ephy_marshal_STRING__STRING_STRING (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
@@ -519,7 +568,7 @@ ephy_marshal_STRING__STRING_STRING (GClosure     *closure,
   g_value_take_string (return_value, v_return);
 }
 
-/* STRING:VOID (./ephy-marshal.list:11) */
+/* STRING:VOID (./ephy-marshal.list:12) */
 extern void ephy_marshal_STRING__VOID (GClosure     *closure,
                                        GValue       *return_value,
                                        guint         n_param_values,
@@ -562,10 +611,10 @@ ephy_marshal_STRING__VOID (GClosure     *closure,
   g_value_take_string (return_value, v_return);
 }
 
-/* VOID:ENUM (./ephy-marshal.list:12) */
+/* VOID:ENUM (./ephy-marshal.list:13) */
 #define ephy_marshal_VOID__ENUM	g_cclosure_marshal_VOID__ENUM
 
-/* VOID:POINTER,BOOLEAN (./ephy-marshal.list:13) */
+/* VOID:POINTER,BOOLEAN (./ephy-marshal.list:14) */
 extern void ephy_marshal_VOID__POINTER_BOOLEAN (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
@@ -608,7 +657,7 @@ ephy_marshal_VOID__POINTER_BOOLEAN (GClosure     *closure,
             data2);
 }
 
-/* VOID:POINTER,POINTER (./ephy-marshal.list:14) */
+/* VOID:POINTER,POINTER (./ephy-marshal.list:15) */
 extern void ephy_marshal_VOID__POINTER_POINTER (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
@@ -651,7 +700,7 @@ ephy_marshal_VOID__POINTER_POINTER (GClosure     *closure,
             data2);
 }
 
-/* VOID:STRING,FLAGS (./ephy-marshal.list:15) */
+/* VOID:STRING,FLAGS (./ephy-marshal.list:16) */
 extern void ephy_marshal_VOID__STRING_FLAGS (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
@@ -694,7 +743,7 @@ ephy_marshal_VOID__STRING_FLAGS (GClosure     *closure,
             data2);
 }
 
-/* VOID:STRING,INT (./ephy-marshal.list:16) */
+/* VOID:STRING,INT (./ephy-marshal.list:17) */
 extern void ephy_marshal_VOID__STRING_INT (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
@@ -737,7 +786,7 @@ ephy_marshal_VOID__STRING_INT (GClosure     *closure,
             data2);
 }
 
-/* VOID:STRING,STRING (./ephy-marshal.list:17) */
+/* VOID:STRING,STRING (./ephy-marshal.list:18) */
 extern void ephy_marshal_VOID__STRING_STRING (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
@@ -780,7 +829,7 @@ ephy_marshal_VOID__STRING_STRING (GClosure     *closure,
             data2);
 }
 
-/* VOID:STRING,STRING,STRING (./ephy-marshal.list:18) */
+/* VOID:STRING,STRING,STRING (./ephy-marshal.list:19) */
 extern void ephy_marshal_VOID__STRING_STRING_STRING (GClosure     *closure,
                                                      GValue       *return_value,
                                                      guint         n_param_values,
