@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-toolbar.c,v 1.27 2005/11/08 12:56:23 chpe Exp $
+ *  $Id: ephy-toolbar.c,v 1.28 2005/11/12 20:48:16 philipl Exp $
  */
 
 #include "config.h"
@@ -363,6 +363,12 @@ ephy_toolbar_set_window (EphyToolbar *toolbar,
 
 /* public functions */
 
+GtkActionGroup *
+ephy_toolbar_get_action_group (EphyToolbar *toolbar)
+{
+   return toolbar->priv->action_group;   
+}
+
 void
 ephy_toolbar_set_favicon (EphyToolbar *toolbar,
 			  GdkPixbuf *icon)
