@@ -14,6 +14,8 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *
+ *  $Id: popup-commands.h,v 1.11 2005/09/26 19:22:18 jframeau Exp $
  */
 
 #include <gtk/gtkaction.h>
@@ -26,24 +28,9 @@ void popup_cmd_link_in_new_window		(GtkAction *action,
 void popup_cmd_link_in_new_tab		(GtkAction *action,
 					 EphyWindow *window);
 
-void popup_cmd_image_in_new_tab		(GtkAction *action,
-					 EphyWindow *window);
-
-void popup_cmd_image_in_new_window	(GtkAction *action,
-					 EphyWindow *window);
-
 void popup_cmd_bookmark_link	(GtkAction *action,
 					 EphyWindow *window);
 
-void popup_cmd_frame_in_new_tab		(GtkAction *action,
-					 EphyWindow *window);
-
-void popup_cmd_frame_in_new_window	(GtkAction *action,
-					 EphyWindow *window);
-
-void popup_cmd_add_frame_bookmark	(GtkAction *action,
-					 EphyWindow *window);
-
 void popup_cmd_view_source		(GtkAction *action,
 					 EphyWindow *window);
 
@@ -59,15 +46,15 @@ void popup_cmd_open_link		(GtkAction *action,
 void popup_cmd_download_link		(GtkAction *action,
 					 EphyWindow *window);
 
+void popup_cmd_download_link_as		(GtkAction *action,
+					 EphyWindow *window);
+
 void popup_cmd_set_image_as_background  (GtkAction *action,
 					 EphyWindow *window);
 
 void popup_cmd_copy_image_location	(GtkAction *action,
 					 EphyWindow *window);
 
-void popup_cmd_save_background_as	(GtkAction *action,
-					 EphyWindow *window);
-
 void popup_cmd_open_frame		(GtkAction *action,
 					 EphyWindow *window);
 
